import requests

def taxation(taxable_income , gross_income , deductions):
		taxable_income = gross_income - deductions
		tax_liability = Taxable income x Tax rate
		print(response.text)
		return response.text

